<?php

/**
 * @file
 * Administrative forms and functions for the entitlements module.
 */

function entitlements_list() {
  require_once(drupal_get_path('module', 'entitlements') .'/entitlements.inc');

  $output = '';

  $avail_entitlements = array();

  $modules = module_implements('entitlements');
  if ($modules) {
    $avail_entitlements = array();
    foreach ($modules as $module) {
      $entitlement_list = module_invoke($module, 'entitlements', 'list');

      if (count($entitlement_list)) {
        $avail_entitlements = array_merge($avail_entitlements, $entitlement_list);
      }
    }

    $avail_entitlements = array_diff($avail_entitlements, _entitlements_load_all_eids());
  }

  foreach ($avail_entitlements as $key => $value) {
    if (user_access('edit entitlements') || user_access('administer entitlements')) {
      $avail_entitlements[$key] = $value . ' (' . l('create', 'admin/user/entitlements/add', array('query' => 'eid=' . $value)) . ')';
    }
  }

  $headers = array(
    array('data' => 'Entitlement', 'field' => 'eid'),
    array('data' => 'Entitlement name', 'field' => 'title'),
  );

  if (user_access('edit entitlements') || user_access('administer entitlements')) {
    $headers[] = array('data' => 'Actions');
  }


  $result = db_query('SELECT eid, title FROM {entitlements}' . tablesort_sql($headers));

  $rows = array();
  while ($row = db_fetch_array($result)) {
    if (user_access('edit entitlements') || user_access('administer entitlements')) {
      $row['actions'] = l('Edit', 'admin/user/entitlements/' . $row['eid'] . '/edit');
      $row['actions'] .= ' ' . l('Delete', 'admin/user/entitlements/' . $row['eid'] . '/delete');
      $row['eid'] = l($row['eid'], 'admin/user/entitlements/' . $row['eid']);
    }
    $rows[] = $row;
  }

  $output .= theme('table', $headers, $rows);

  if (count($avail_entitlements)) {
    $output .= '<h3>Available Entitlements</h3>';
    $output .= theme('item_list', $avail_entitlements);
  }

  return $output;
}

function entitlements_edit_form($form_state, $eid = NULL) {
  require_once(drupal_get_path('module', 'entitlements') . '/entitlements.inc');

  $form = array();

    
  $entitlement = new stdClass();
  if (!$eid) {
    $form['eid'] = array(
      '#title' => 'Entitlement name',
      '#type' => 'textfield',
      '#required' => TRUE,
    );
  }
  else {
    $entitlement = _entitlements_load($eid);
    $form['eid_text'] = array(
      '#value' => '<strong>' . t('Entitlement name') . '</strong>: ' . $entitlement->eid,
    );
    $form['eid'] = array(
      '#type' => 'value',
      '#value' => $entitlement->eid,
    );
  }


  $form['title'] = array(
    '#title' => 'Title',
    '#type' => 'textfield',
    '#required' => TRUE,
    '#maxsize' => 255,
    '#default_value' => $entitlement->title,
  );

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => 'Save',
  );

  $form['cancel'] = array(
    '#type' => 'submit',
    '#value' => 'Cancel',
  );

  if (arg(3) != 'add') {
    $form['eid']['#disabled'] = TRUE;
  }

  $form['#redirect'] = 'admin/user/entitlements';

  return $form;
}

function entitlements_edit_form_submit($form, &$form_state) {
  if ($form_state['clicked_button']['#value'] == 'Cancel') return;

  $entitlement = new stdClass();
  $entitlement->eid = $form_state['values']['eid'];
  $entitlement->title = $form_state['values']['title'];

  if (arg(3) && arg(3) != 'add') {
    $entitlement->eid = arg(3);
    $primary_keys = array('eid');
  }

  $result = drupal_write_record('entitlements', $entitlement, isset($primary_keys) ? $primary_keys : NULL);

  switch ($result) {
    case SAVED_NEW:
      drupal_set_message('New entitlement successfully created.');
      break;
    case SAVED_UPDATED:
      drupal_set_message('Entitlement successfully updated.');
      break;
    default:
      form_set_error('Unable to update entitlement.');
  }
}

function entitlements_import_form() {
  
}

function entitlements_export_form() {
  
}

function entitlements_delete_entitlement($eid) {
  module_load_include('inc', 'entitlements');
  _entitlements_delete($eid);
  drupal_goto(referer_uri());
}

function entitlements_admin_form() {
  $form['entitlements_refresh'] = array(
    '#title' => t('Refresh period'),
    '#type' => 'select',
    '#description' => t('Entitlements will be reprocessed periodically based on this setting.'),
    '#options' => drupal_map_assoc(array(60, 120, 300, 600, 900, 1800, 3600, 7200, 14400, 43200, 86400), 'format_interval'),
    '#required' => TRUE,
    '#default_value' => variable_get('entitlements_refresh', 3600),
  );
  
  return system_settings_form($form);
}