<?php

/**
 * @file
 * Administration forms and functions for the og_entitlements module.
 */

function og_entitlements_admin_form($form_id) {
  require_once(drupal_get_path('module', 'entitlements') .'/entitlements.inc');

  $form = array();
  $groups = _og_entitlements_get_groups();
  
  if (!count($groups)) {
    return array(
      'no_groups' => array('#value' => t('No groups found.')),
    );
  }
  
  foreach ($groups as $nid => $group_name) {
    $group = node_load($nid);
    $groups[$group->uuid] = $group_name;
    unset($groups[$nid]);
  }
  
  $groups[0] = '';
  asort($groups, SORT_STRING);
  $group_selects = array();

  $result = db_query('SELECT DISTINCT eid, title FROM {entitlements} ORDER BY title ASC');

  while ($row = db_fetch_object($result)) {
    $entitlement = _entitlements_load($row->eid);

    $form['entitlement_' . $entitlement->eid] = array(
      '#type' => 'select',
      '#title' => $entitlement->title . ' (' . $entitlement->eid . ')',
      '#default_value' => $entitlement->group_uuid,
      '#name' => 'entitlement_' . $entitlement->eid,
      '#id' => 'entitlement_' . $entitlement->eid,
      '#options' => $groups,
    );
  }

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
  );

  return $form;
}

function og_entitlements_admin_form_submit($form, &$form_state) {
  $entitlements_values = array();

  $matches = array();
  foreach ($form_state['values'] as $key => $value) {
    if (preg_match('/entitlement_([A-Za-z0-9]+)/', $key, $matches)) {
      $entitlements_values[$matches[1]] = $value;
    }
  }

  // reset entire table because submitted form represents all rows
  db_query('TRUNCATE {og_entitlements}');

  $entitlement = new stdClass();
  foreach ($entitlements_values as $eid => $uuid) {
    $entitlement->eid = $eid;
    $entitlement->uuid = $uuid;
    drupal_write_record('og_entitlements', $entitlement);
  }

  drupal_set_message('Mappings successfully saved.');
}

function og_entitlements_import_form() {
  $form['export_form']['import_code'] = array(
    '#type' => 'textarea',
    '#description' => t('Paste in code from the Export tab of another site. <strong>WARNING: This will overwrite any current mappings!'),
    '#rows' => 20,
  );
  
  $form['import_form']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Import'),
  );
  
  return $form;
}

function og_entitlements_import_form_submit($form, &$form_state) {
  $import_code = $form_state['values']['import_code'];
  if ($import_code !== FALSE) {
    @eval($import_code);
    
    if (is_array($mappings)) {
      foreach ($mappings as $import_mapping) {
        $mapping = new stdClass();
        $mapping->eid = $import_mapping['eid'];
        $mapping->uuid = $import_mapping['uuid'];
        
        // check for current mapping
        $result = db_query('SELECT COUNT(eid) FROM og_entitlements WHERE eid = "%s"', $mapping->eid);
        if (db_result($result)) {
          drupal_write_record('og_entitlements', $mapping, array('eid'));
        }
        else {
          drupal_write_record('og_entitlements', $mapping);
        }
      }
    }
  }
}

function og_entitlements_export_form() {
  $result = db_query('SELECT eid, uuid FROM og_entitlements');

  $og_mappings = array();
  while ($row = db_fetch_array($result)) {
    if ($row['uuid']) {
      $og_mappings[] = $row;
    }
  }

  if (count($og_mappings)) {
    $form['export_form']['exported_code'] = array(
      '#type' => 'textarea',
      '#description' => t('Copy this code and paste into the Import tab of another site.'),
      '#rows' => 20,
      '#default_value' => '$mappings = ' . var_export($og_mappings, TRUE) . ';',
    );
  }
  else {
    $form['export_form']['no_mappings'] = array(
      '#value' => t('No mappings to export.'),
    );
  }

  return $form;
}
